@@ -6,7 +6,9 @@ from .models import UserPagination, User
 from .grpc_client import AccountServiceGRPCClient
 
 __all__ = [
-    "init_service"
+    'init_service',
+    'get_user_list',
+    'get_user_page_list'
 ]
 
 _client: AccountServiceGRPCClient
